@@ -10,7 +10,7 @@ from vsutil import depth, get_y, iterate, join, split
 from vsutil import Range as CRange
 
 from . import util
-from .misc import replace_ranges, scale_thresh
+from .util import replace_ranges, scale_thresh
 from .types import Position, Range, Size
 
 core = vs.core
@@ -198,7 +198,7 @@ class BoundingBox():
         :return:    Square mask representing the bounding box.
         """
         if ref.format is None:
-            raise ValueError("get_all_masks: 'Variable-format clips not supported'")
+            raise ValueError("BoundingBox: 'Variable-format clips not supported'")
 
         if self.pos.x + self.size.x > ref.width or self.pos.y + self.size.y > ref.height:
             raise ValueError("BoundingBox: Bounds exceed clip size!")
@@ -232,7 +232,7 @@ class DeferredMask(ABC):
     """
     ranges: List[Range]
     bound: Optional[BoundingBox]
-    refframes: List[int]
+    refframes: List[Optional[int]]
     blur: bool
 
     def __init__(self, ranges: Union[Range, List[Range]],
@@ -254,10 +254,10 @@ class DeferredMask(ABC):
         elif isinstance(refframes, int):
             self.refframes = [refframes] * len(self.ranges)
         else:
-            self.refframes = refframes
+            self.refframes = [x for x in refframes]  # wtf mypy
 
         if len(self.refframes) > 0 and len(self.refframes) != len(self.ranges):
-            raise ValueError("Mask: 'Received reference frame and range list size mismatch!'")
+            raise ValueError("DeferredMask: 'Received reference frame and range list size mismatch!'")
 
     def get_mask(self, clip: vs.VideoNode, ref: vs.VideoNode) -> vs.VideoNode:
         """
@@ -269,7 +269,7 @@ class DeferredMask(ABC):
         :return:      Bounded mask
         """
         if ref.format is None or clip.format is None:
-            raise ValueError("get_all_masks: 'Variable-format clips not supported'")
+            raise ValueError("get_mask: 'Variable-format clips not supported'")
 
         if self.bound:
             bm = self.bound.get_mask(ref)
@@ -282,6 +282,10 @@ class DeferredMask(ABC):
             hm = core.std.BlankClip(ref, format=ref.format.replace(color_family=vs.GRAY,
                                                                    subsampling_h=0, subsampling_w=0).id)
             for range, rf in zip(self.ranges, self.refframes):
+                if rf is None:
+                    rf = ref.num_frames - 1
+                elif rf < 0:
+                    rf = ref.num_frames - 1 + rf
                 mask = depth(self._mask(clip[rf], ref[rf]), clip.format.bits_per_sample,
                              range=CRange.FULL, range_in=CRange.FULL)
                 hm = replace_ranges(hm, core.std.Expr([hm, mask*len(hm)], expr="x y max"), range)
