@@ -5,13 +5,17 @@ import colorsys
 import os
 import random
 from functools import partial, wraps
-from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, TypeVar, Union, cast
+from typing import (Any, Callable, Dict, List, Optional, Sequence, Tuple,
+                    TypeVar, Union, cast)
 
 import vapoursynth as vs
 from vsutil import get_depth, get_w, get_y, is_image, scale_value
 
+from .mask import BoundingBox
+from .types import Position, Size
 from .util import get_prop
-from .types import Range
+from .util import replace_ranges as _replace_ranges
+from .util import scale_thresh as _scale_thresh
 
 core = vs.core
 
@@ -57,9 +61,9 @@ def source(file: str, ref: Optional[vs.VideoNode] = None,
 
     # Error handling for some file types
     if file.endswith('.mpls') and mpls is False:
-        raise ValueError("source: 'Please set \"mpls = True\" and give a path to the base Blu-ray directory when trying to load in mpls files'")  # noqa: E501
+        raise ValueError("source: 'Set \"mpls = True\" and pass a path to the base Blu-ray directory for this kind of file'")  # noqa: E501
     if os.path.splitext(file)[1].lower() in annoying_formats:
-        raise ValueError("source: 'Please use an external indexer like d2vwitch or DGIndexNV for this file and import that'")  # noqa: E501
+        raise ValueError("source: 'Use an external indexer like d2vwitch or DGIndexNV for this kind of file'")  # noqa: E501
 
     if force_lsmas:
         clip = core.lsmas.LWLibavSource(file, **index_args)
@@ -93,45 +97,6 @@ def source(file: str, ref: Optional[vs.VideoNode] = None,
     return clip
 
 
-def replace_ranges(clip_a: vs.VideoNode,
-                   clip_b: vs.VideoNode,
-                   ranges: Union[Range, List[Range]]) -> vs.VideoNode:
-    """
-    A replacement for ReplaceFramesSimple that uses ints and tuples rather than a string.
-    Frame ranges are inclusive.
-
-    Written by louis.
-
-    Alias for this function is `lvsfunc.rfs`.
-
-    :param clip_a:     Original clip
-    :param clip_b:     Replacement clip
-    :param ranges:     Ranges to replace clip_a (original clip) with clip_b (replacement clip).
-                       Integer values in the list indicate single frames,
-                       Tuple values indicate inclusive ranges.
-
-    :return:           Clip with ranges from clip_a replaced with clip_b
-    """
-    if not isinstance(ranges, list):
-        ranges = [ranges]
-
-    out = clip_a
-
-    for r in ranges:
-        if type(r) is tuple:
-            start, end = cast(Tuple[int, int], r)
-        else:
-            start = cast(int, r)
-            end = cast(int, r)
-        tmp = clip_b[start:end + 1]
-        if start != 0:
-            tmp = out[: start] + tmp
-        if end < out.num_frames - 1:
-            tmp = tmp + out[end + 1:]
-        out = tmp
-    return out
-
-
 def edgefixer(clip: vs.VideoNode,
               left: Union[int, List[int], None] = None,
               right: Union[int, List[int], None] = None,
@@ -271,51 +236,33 @@ def limit_dark(clip: vs.VideoNode, filtered: vs.VideoNode,
 
 
 def wipe_row(clip: vs.VideoNode,
-             secondary: Optional[vs.VideoNode] = None,
-             width: int = 1, height: int = 1,
-             offset_x: int = 0, offset_y: int = 0,
-             width2: Optional[int] = None, height2: Optional[int] = None,
-             offset_x2: Optional[int] = None, offset_y2: Optional[int] = None,
-             show_mask: bool = False) -> vs.VideoNode:
+             ref: Optional[vs.VideoNode] = None,
+             pos: Union[Position, Tuple[int, int]] = (1, 1),
+             size: Optional[Union[Size, Tuple[int, int]]] = None,
+             show_mask: bool = False
+             ) -> vs.VideoNode:
     """
-    Simple function to wipe a row with a blank clip.
+    Simple function to wipe a row or column with a blank clip.
     You can also give it a different clip to replace a row with.
 
-    if width2, height2, etc. are given, it will merge the two masks.
-
-    Dependencies:
-    * kagefunc
-
     :param clip:           Input clip
     :param secondary:      Clip to replace wiped rows with (Default: None)
     :param width:          Width of row (Default: 1)
     :param height:         Height of row (Default: 1)
     :param offset_x:       X-offset of row (Default: 0)
     :param offset_y:       Y-offset of row (Default: 0)
-    :param width2:         Width of row 2 (Default: None)
-    :param height2:        Height of row 2 (Default: None)
-    :param offset_x2:      X-offset of row 2 (Default: None)
-    :param offset_y2:      Y-offset of row 2 (Default: None)
 
-    :return:               Clip with rows wiped
+    :return:               Clip with given rows or columns wiped
     """
-    try:
-        import kagefunc as kgf
-    except ModuleNotFoundError:
-        raise ModuleNotFoundError("wipe_row: missing dependency 'kagefunc'")
+    ref = ref or core.std.BlankClip(clip)
 
-    secondary = secondary or core.std.BlankClip(clip)
-
-    sqmask = kgf.squaremask(clip, width, height, offset_x, offset_y)
-    if width2 and height2:
-        if offset_x2 is None:
-            raise TypeError("wipe_row: 'offset_x2 cannot be None if using two masks'")
-        sqmask2 = kgf.squaremask(clip, width2, height2, offset_x2, offset_y - 1 if offset_y2 is None else offset_y2)
-        sqmask = core.std.Expr([sqmask, sqmask2], "x y +")
+    if size is None:
+        size = (clip.width-2, clip.height-2)
+    sqmask = BoundingBox(pos, size).get_mask(clip)
 
     if show_mask:
         return sqmask
-    return core.std.MaskedMerge(clip, secondary, sqmask)
+    return core.std.MaskedMerge(clip, ref, sqmask)
 
 
 def load_bookmarks(bookmark_path: str) -> List[int]:
@@ -526,27 +473,9 @@ def colored_clips(amount: int,
     return [core.std.BlankClip(color=color, **blank_clip_args) for color in rgb_color_list]
 
 
-def scale_thresh(thresh: float, clip: vs.VideoNode, assume: Optional[int] = None) -> float:
-    """
-    Scale binarization thresholds from float to int.
-
-    :param thresh: Threshold [0, 1]. If greater than 1, assumed to be in native clip range
-    :param clip:   Clip to scale to
-    :param assume: Assume input is this depth when given input >1. If ``None``\\, assume ``clip``\\'s format.
-                   (Default: None)
-
-    :return:       Threshold scaled to [0, 2^clip.depth - 1] (if vs.INTEGER)
-    """
-    if clip.format is None:
-        raise ValueError("scale_thresh: 'Variable-format clips not supported.'")
-    if thresh < 0:
-        raise ValueError("scale_thresh: 'Thresholds must be positive.'")
-    if thresh > 1:
-        return thresh if not assume \
-            else round(thresh/((1 << assume) - 1) * ((1 << clip.format.bits_per_sample) - 1))
-    return thresh if clip.format.sample_type == vs.FLOAT or thresh > 1 \
-        else round(thresh * ((1 << clip.format.bits_per_sample) - 1))
-
+# compatibility since these were moved to util
+replace_ranges = _replace_ranges
+scale_thresh = _scale_thresh
 
 # TODO: Write function that only masks px of a certain color/threshold of colors.
 #       Think the magic wand tool in various image-editing programs.
